<?PHP
/* Structure of array:
0: name of element
1: mandatory? (y or n)
2: format (eg. text/utf8
3: allowed values (eg. "m", "cm", ...)
4: dependent fields
5: remarks
*/
$allowed = array(
array ('inventory_number','y','text/utf8','freetext','none','Only unique values allowed'),
array ('institution_name','n','text/utf8','freetext','none','If name of institution is given it has to be exactly the same as already known in museum-digital'),
array ('collection_name1','n','text/utf8','freetext','none','Use if object belongs to a collection. If collection is already in museum-digital, please use exactly the same name'),
array ('collection_name2','n','text/utf8','freetext','none','Use if the object belongs to a second collection. If collection is already in museum-digital, please use exactly the same name'),
array ('object_type','y','text/utf8','freetext','none','Keep it short! Field is needed to create valid LIDO from museum-digital entries'),
array ('object_title','y','text/utf8','freetext','none','Best is not to repeat the title again and again for many objects, e.g. vase, vase, vase ... better: Green vase, Blue vase, Yellow vase, ...'),
array ('object_description','y','text/utf8','freetext','none','A good description of the objects is fundamental to make the objects searchable in the internet'),
array ('object_material_technique','n','text/utf8','freetext','none','This is a cummulative field for material and technique. It is also possible to additionally save the information separate in the fields: <i>material_separate</i> and <i>technique_separate</i>'),
array ('object_dimensions','n','text/utf8','freetext','none','This is a cummulative field for dimensions (values and units). It is also possible to additionally save the information separate. See the block: <i>separate dimensions</i>'),
array ('object_publication','n','One letter only','"y","n"','none','Shall the object be visible directly after import?'),
array ('object_other_title','n','text/utf8','freetext','object_other_title_kind_of','If the field <i>object_other_title</i> is used. It has to be specified where this alternative title is used. Specification should be done within the field: <i>object_other_title_kind_of</i>'),
array ('object_other_title_kind_of','n','text/utf8','de: "Wissenschaft", "Alltagssprache", "Umgangssprache", "Dialekt"<br>hu: "Tudományos", "Köznyelvi", "Nyelvjárás"', 'object_other_title', 'This field has to be used togehter with <i>object_other_title</i>'),
array ('detailed_description','n','text/utf8','freetext','detailed_description_md and detailed_description_extern','If <i>detailed_desription</i> is made available for an object, <i>detailed_description_md</i> and <i>detailed_description_extern</i> have to have values too'),
array ('detailed_description_md','n','One letter only','"y","n"','detailed_description and detailed_description_extern','Shall detailed description be visible at museum-digital? If <i>detailed_desription</i> is available for an object, <i>detailed_description_md</i> and <i>detailed_description_extern</i> have to have values too'),
array ('detailed_description_extern','n','One letter only','"y","n"','detailed_description_md and detailed_description','Shall later exports from museum-digital include the detailed_description?</br>If <i>detailed_desription</i> is available for an object, <i>detailed_description_md</i> and <i>detailed_description_extern</i> have to have values too'),
array ('inscription','n','text/utf8','freetext','inscription_md and inscription_extern','If <i>inscription</i> is made available for an object, <i>inscription_md></i> and <i>inscription_extern</i> have to have values too'),
array ('inscription_md','n','One letter only','"y","n"','inscription_md and inscription_extern','Shall a given inscription be displayed at museum-digital? If <i>inscription</i> is available for an object, <i>inscription_md></i> and <i>inscription_extern</i> have to have values too'),
array ('inscription_extern','n','One letter only','"y","n"','inscription_md and inscription_extern','Shall later exports from museum-digital inlude inscription? If <i>inscription</i> is available for an object, <i>inscription_md></i> and <i>inscription_extern</i> have to have values too'),
array ('material_separate','n','text/utf8','freetext','none','Additional to collecting material and technique in a combined field (see above), the material(s) can be given here separately'),
array ('technique_separate','n','text/utf8','freetext','none', 'Additional to collecting material and technique in a combined field (see above), the technique(s) can be given here separately'),
array ('dimensions_separate_length_value','n','text/utf8','number','dimensions_separate_length_unit, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_length_unit','n','text/utf8','"m","dm","cm","mm"','dimensions_separate_length_value, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_width_value', 'n', 'text/utf8', 'number','dimensions_separate_width_unit, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_width_unit', 'n', 'text/utf8', '"m","dm","cm","mm"','dimensions_separate_width_value, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_height_value', 'n', 'text/utf8', 'number','dimensions_separate_height_unit, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_height_unit', 'n', 'text/utf8', '"m","dm","cm","mm"','dimensions_separate_height_value, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_weight_value', 'n', 'text/utf8','number','dimensions_separate_weight_unit, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_weight_unit', 'n', 'text/utf8', '"m","dm","cm","mm"','dimensions_separate_width_value, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_diameter_value', 'n', 'text/utf8', 'number','dimensions_separate_diameter_unit, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_diameter_unit', 'n', 'text/utf8', '"m","dm","cm","mm"','dimensions_separate_diameter_value, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_wall_thickness_value', 'n', 'text/utf8', 'number','dimensions_separate_thickness_unit, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_wall_thickness_unit', 'n', 'text/utf8', '"m","dm","cm","mm"','dimensions_separate_thickness_value, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_show_md', 'n', 'One letter only', '"y","n"','Any field named dimensions_separate ...','If one or more separate dimension-value (and -unit) is given it has to be specified if the separated entries should be made visible at museum-digital'),
array ('dimensions_separate_show_extern', 'n', 'One letter only', '"y","n"','Any field named dimensions_separate ...','If one or more separate dimension-value (and -unit) is given it has to be specified if the separated entries should be included in a later export from museum-digital'),
array ('number_of_pieces', 'n', 'text/utf8','number','none','Only to be given if more than one copies of an object are available and catalogued with the same inventory number'),
array ('number_of_pages', 'n', 'text/utf8', 'number', 'none','Only to be given for books (etc.)'),
array ('comparable_objects_other_museums', 'n', 'text/utf8', 'freetext', 'comparable_objects_other_museums_show_md, comparable_objects_other_museums_show_extern', 'Name of other museum and if available the inventory number of the respective object. If <i>comparable_objects_other_museums</i> is given <i>comparable_objects_other_museums_show_md</i> and <i>comparable_objects_other_museums_show_extern</i> have to be given too'),
array ('comparable_objects_other_museums_show_md', 'n', 'One letter only', '"y","n"', 'comparable_objects_other_museums','Necessary if <i>comparable_objects_other_museums</i> is given. Should the information about comparable objects be displayed at museum-digital?'),
array ('comparable_objects_other_museums_show_extern', 'n', 'One letter only', '"y","n"', 'comparable_objects_other_museums','Necessary if <i>comparable_objects_other_museums</i> is given. Should the information about comparable objects be part of later exports from museum-digital?'),
//array ('other_object_title', 'n', ''),
//array ('other_object_title_in', 'n', ''),
array ('closer_location', 'n', 'text/utf8', 'freetext', 'closer_location_as', 'A place in a special relation to the object. The kind of relation has to specified in <i>closer_location_as</i>'),
array ('closer_location_as', 'n', 'text/utf8', 'de: "Aufnahmeort", "Fundort", "Früherer Ort"&#10;hu: "Felvétel késztésének helye","Lelőhely","Történelmi elnevezés"', 'closer_location', 'A place in a special relation to the object can be given in <i>closer_location</i>. Here the kind of relation between object and place has to specified'),
/* Structure of array:
0: name of element
1: mandatory? (y or n)
2: format (eg. text/utf8
3: allowed values (eg. "m", "cm", ...)
4: dependent fields
5: remarks
*/
array ('entry_number', 'n', 'text/utf8','freetext','none','The entry number of the object if available'),
array ('other_inventory_number', 'n', 'text/utf8','freetext','none','All other inventory numbers (older ones presumably) in one field'),
array ('subject_group', 'n', 'text/utf8','freetext','none','If the object is part of an subject group this information should be given here'),
array ('systematic', 'n', 'text/utf8','freetext','none','If the object is put into a museum-systematic the place it has there'),
array ('bundle', 'n', 'text/utf8','freetext','none','The bundle the object belongs to'),
array ('part_of', 'n', 'text/utf8','freetext','none','If the object is part of something it can be given here'),
array ('inclusion_when', 'n', ''),
array ('inclusion_kind_of', 'n', ''),
array ('inclusion_who', 'n', ''),
array ('inclusion_where', 'n', ''),
array ('registration_first_who', 'n', ''),
array ('registration_first_when', 'n', ''),
array ('owner_previous', 'n', ''),
array ('object_history', 'n', ''),
array ('bought_for', 'n', ''),
array ('bought_for_currency', 'n', ''),
array ('worth_determiner', 'n', ''),
array ('worth_when', 'n', ''),
array ('worth_value', 'n', ''),
array ('worth_unit', 'n', ''),
array ('worth_incurance_determiner', 'n', ''),
array ('worth_incurance_when', 'n', ''),
array ('worth_insurance_value', 'n', ''),
array ('worth_insurance_unit', 'n', ''),
array ('state', 'n', ''),
array ('restauration', 'n', ''),
array ('abode_actual', 'n', ''),
array ('abode_regular', 'n', ''),
array ('exhibition', 'n', ''),
array ('on_loan_to', 'n', ''),
array ('on_loan_contact', 'n', ''),
array ('on_loan_when', 'n', ''),
array ('on_loan_insurance_value', 'n', ''),
array ('on_loan_annotation', 'n', ''),
array ('copyright', 'n', ''),
array ('rights_of_use', 'n', ''),
array ('rights_annotation', 'n', ''),
array ('remarks_short', 'n', ''),
array ('remarks_long', 'n', ''),
array ('images_in_museum', 'n', ''),
array ('documents_in_museum', 'n', ''),
array ('link_url1', 'n', ''),
array ('link_show1', 'n', ''),
array ('link_url2', 'n', ''),
array ('link_show2', 'n', ''),
array ('literature_author1', 'n', ''),
array ('literature_year1', 'n', ''),
array ('literature_title1', 'n', ''),
array ('literature_place1', 'n', ''),
array ('literature_abbreviation1', 'n', ''),
array ('literature_gnd1', 'n', ''),
array ('literature_isbn1', 'n', ''),
array ('literature_signature1', 'n', ''),
array ('literature_online1', 'n', ''),
array ('literature_annotation1', 'n', ''),
array ('literature_inlit1', 'n', ''),
array ('literature_author2', 'n', ''),
array ('literature_year2', 'n', ''),
array ('literature_title2', 'n', ''),
array ('literature_place2', 'n', ''),
array ('literature_abbreviation2', 'n', ''),
array ('literature_gnd2', 'n', ''),
array ('literature_isbn2', 'n', ''),
array ('literature_signature2', 'n', ''),
array ('literature_online2', 'n', ''),
array ('literature_annotation2', 'n', ''),
array ('literature_inlit2', 'n', ''),
array ('object_group_name1', 'n', ''),
array ('object_group_description1', 'n', ''),
array ('object_group_show1', 'n', ''),
array ('object_group_name2', 'n', ''),
array ('object_group_description2', 'n', ''),
array ('object_group_show2', 'n', ''),
array ('object_group_name3', 'n', ''),
array ('object_group_description3', 'n', ''),
array ('object_group_show3', 'n', ''),
array ('object_group_name4', 'n', ''),
array ('object_group_description4', 'n', ''),
array ('object_group_show4', 'n', ''),
array ('object_group_name5', 'n', ''),
array ('object_group_description5', 'n', ''),
array ('object_group_show5', 'n', ''),
array ('tag1', 'n', ''),
array ('tag2', 'n', ''),
array ('tag3', 'n', ''),
array ('tag4', 'n', ''),
array ('tag5', 'n', ''),
array ('tag6', 'n', ''),
array ('tag7', 'n', ''),
array ('tag8', 'n', ''),
array ('tag9', 'n', ''),
array ('tag10', 'n', ''),
array ('related_place1', 'n', ''),
array ('related_place_sure1', 'n', ''),
array ('related_place2', 'n', ''),
array ('related_place_sure2', 'n', ''),
array ('related_actor1', 'n', ''),
array ('related_actor_sure1', 'n', ''),
array ('related_actor2', 'n', ''),
array ('related_actor_sure2', 'n', ''),
array ('related_time1', 'n', ''),
array ('related_time_sure1', 'n', ''),
array ('related_time2', 'n', ''),
array ('related_time_sure2', 'n', ''),
array ('image_name1', 'n', ''),
array ('image_description1', 'n', ''),
array ('image_owner1', 'n', ''),
array ('image_creator1', 'n', ''),
array ('image_rights1', 'n', ''),
array ('image_visible1', 'n', ''),
array ('image_main1', 'n', ''),
array ('image_name2', 'n', ''),
array ('image_description2', 'n', ''),
array ('image_owner2', 'n', ''),
array ('image_creator2', 'n', ''),
array ('image_rights2', 'n', ''),
array ('image_visible2', 'n', ''),
array ('image_main2', 'n', ''),
array ('image_name3', 'n', ''),
array ('image_description3', 'n', ''),
array ('image_owner3', 'n', ''),
array ('image_creator3', 'n', ''),
array ('image_rights3', 'n', ''),
array ('image_visible3', 'n', ''),
array ('image_main3', 'n', ''),
array ('image_name4', 'n', ''),
array ('image_description4', 'n', ''),
array ('image_owner4', 'n', ''),
array ('image_creator4', 'n', ''),
array ('image_rights4', 'n', ''),
array ('image_visible4', 'n', ''),
array ('image_main4', 'n', ''),
array ('image_name5', 'n', ''),
array ('image_description5', 'n', ''),
array ('image_owner5', 'n', ''),
array ('image_creator5', 'n', ''),
array ('image_rights5', 'n', ''),
array ('image_visible5', 'n', ''),
array ('image_main5', 'n', ''),
array ('image_name6', 'n', ''),
array ('image_description6', 'n', ''),
array ('image_owner6', 'n', ''),
array ('image_creator6', 'n', ''),
array ('image_rights6', 'n', ''),
array ('image_visible6', 'n', ''),
array ('image_main6', 'n', ''),
array ('image_name7', 'n', ''),
array ('image_description7', 'n', ''),
array ('image_owner7', 'n', ''),
array ('image_creator7', 'n', ''),
array ('image_rights7', 'n', ''),
array ('image_visible7', 'n', ''),
array ('image_main7', 'n', ''),
array ('image_name8', 'n', ''),
array ('image_description8', 'n', ''),
array ('image_owner8', 'n', ''),
array ('image_creator8', 'n', ''),
array ('image_rights8', 'n', ''),
array ('image_visible8', 'n', ''),
array ('image_main8', 'n', ''),
array ('image_name9', 'n', ''),
array ('image_description9', 'n', ''),
array ('image_owner9', 'n', ''),
array ('image_creator9', 'n', ''),
array ('image_rights9', 'n', ''),
array ('image_visible9', 'n', ''),
array ('image_main9', 'n', ''),
array ('image_name10', 'n', ''),
array ('image_description10', 'n', ''),
array ('image_owner10', 'n', ''),
array ('image_creator10', 'n', ''),
array ('image_rights10', 'n', ''),
array ('image_visible10', 'n', ''),
array ('image_main10', 'n', ''),
array ('resource_media_type1', 'n', ''),
array ('resource_fileformat1', 'n', ''),
array ('resource_location1', 'n', ''),
array ('resource_name1', 'n', ''),
array ('resource_description1', 'n', ''),
array ('resource_owner1', 'n', ''),
array ('resource_creator1', 'n', ''),
array ('resource_rights1', 'n', ''),
array ('resource_visible1', 'n', ''),
array ('resource_media_type2', 'n', ''),
array ('resource_fileformat2', 'n', ''),
array ('resource_location2', 'n', ''),
array ('resource_name2', 'n', ''),
array ('resource_description2', 'n', ''),
array ('resource_owner2', 'n', ''),
array ('resource_creator2', 'n', ''),
array ('resource_rights2', 'n', ''),
array ('resource_visible2', 'n', ''),
array ('production_when1', 'n', ''),
array ('production_when_sure1', 'n', ''),
array ('production_who1', 'n', ''),
array ('production_who_sure1', 'n', ''),
array ('production_where1', 'n', ''),
array ('production_where_sure1', 'n', ''),
array ('production_annotation1', 'n', ''),
array ('production_when2', 'n', ''),
array ('production_when_sure2', 'n', ''),
array ('production_who2', 'n', ''),
array ('production_who_sure2', 'n', ''),
array ('production_where2', 'n', ''),
array ('production_where_sure2', 'n', ''),
array ('production_annotation2', 'n', ''),
array ('finding_when1', 'n', ''),
array ('finding_when_sure1', 'n', ''),
array ('finding_who1', 'n', ''),
array ('finding_who_sure1', 'n', ''),
array ('finding_where1', 'n', ''),
array ('finding_where_sure1', 'n', ''),
array ('finding_annotation1', 'n', ''),
array ('finding_when2', 'n', ''),
array ('finding_when_sure2', 'n', ''),
array ('finding_who2', 'n', ''),
array ('finding_who_sure2', 'n', ''),
array ('finding_where2', 'n', ''),
array ('finding_where_sure2', 'n', ''),
array ('finding_annotation2', 'n', ''),
array ('publication_when1', 'n', ''),
array ('publication_when_sure1', 'n', ''),
array ('publication_who1', 'n', ''),
array ('publication_who_sure1', 'n', ''),
array ('publication_where1', 'n', ''),
array ('publication_where_sure1', 'n', ''),
array ('publication_annotation1', 'n', ''),
array ('publication_when2', 'n', ''),
array ('publication_when_sure2', 'n', ''),
array ('publication_who2', 'n', ''),
array ('publication_who_sure2', 'n', ''),
array ('publication_where2', 'n', ''),
array ('publication_where_sure2', 'n', ''),
array ('publication_annotation2', 'n', ''),
array ('template_creation_when1', 'n', ''),
array ('template_creation_when_sure1', 'n', ''),
array ('template_creation_who1', 'n', ''),
array ('template_creation_who_sure1', 'n', ''),
array ('template_creation_where1', 'n', ''),
array ('template_creation_where_sure1', 'n', ''),
array ('template_creation_annotation1', 'n', ''),
array ('template_creation_when2', 'n', ''),
array ('template_creation_when_sure2', 'n', ''),
array ('template_creation_who2', 'n', ''),
array ('template_creation_who_sure2', 'n', ''),
array ('template_creation_where2', 'n', ''),
array ('template_creation_where_sure2', 'n', ''),
array ('template_creation_annotation2', 'n', ''),
array ('was_depicted_who1', 'n', ''),
array ('was_depicted_who_sure1', 'n', ''),
array ('was_depicted_who2', 'n', ''),
array ('was_depicted_who_sure2', 'n', ''),
array ('was_depicted_place1', 'n', ''),
array ('was_depicted_place_sure1', 'n', ''),
array ('was_depicted_place2', 'n', ''),
array ('was_depicted_place_sure2', 'n', ''),
array ('was_used_when1', 'n', ''),
array ('was_used_when_sure1', 'n', ''),
array ('was_used_who1', 'n', ''),
array ('was_used_who_sure1', 'n', ''),
array ('was_used_where1', 'n', ''),
array ('was_used_where_sure1', 'n', ''),
array ('was_used_annotation1', 'n', ''),
array ('was_used_when2', 'n', ''),
array ('was_used_when_sure2', 'n', ''),
array ('was_used_who2', 'n', ''),
array ('was_used_who_sure2', 'n', ''),
array ('was_used_where2', 'n', ''),
array ('was_used_where_sure2', 'n', ''),
array ('was_used_annotation2', 'n', ''),
array ('written_when1', 'n', ''),
array ('written_when_sure1', 'n', ''),
array ('written_who1', 'n', ''),
array ('written_who_sure1', 'n', ''),
array ('written_where1', 'n', ''),
array ('written_where_sure1', 'n', ''),
array ('written_annotation1', 'n', ''),
array ('written_when2', 'n', ''),
array ('written_when_sure2', 'n', ''),
array ('written_who2', 'n', ''),
array ('written_who_sure2', 'n', ''),
array ('written_where2', 'n', ''),
array ('written_where_sure2', 'n', ''),
array ('written_annotation2', 'n', ''),
array ('collected_when1', 'n', ''),
array ('collected_when_sure1', 'n', ''),
array ('collected_who1', 'n', ''),
array ('collected_who_sure1', 'n', ''),
array ('collected_where1', 'n', ''),
array ('collected_where_sure1', 'n', ''),
array ('collected_annotation1', 'n', ''),
array ('collected_when2', 'n', ''),
array ('collected_when_sure2', 'n', ''),
array ('collected_who2', 'n', ''),
array ('collected_who_sure2', 'n', ''),
array ('collected_where2', 'n', ''),
array ('collected_where_sure2', 'n', ''),
array ('collected_annotation2', 'n', ''),
array ('painted_when1', 'n', ''),
array ('painted_when_sure1', 'n', ''),
array ('painted_who1', 'n', ''),
array ('painted_who_sure1', 'n', ''),
array ('painted_where1', 'n', ''),
array ('painted_where_sure1', 'n', ''),
array ('painted_annotation1', 'n', ''),
array ('painted_when2', 'n', ''),
array ('painted_when_sure2', 'n', ''),
array ('painted_who2', 'n', ''),
array ('painted_who_sure2', 'n', ''),
array ('painted_where2', 'n', ''),
array ('painted_where_sure2', 'n', ''),
array ('painted_annotation2', 'n', ''),
array ('taken_when1', 'n', ''),
array ('taken_when_sure1', 'n', ''),
array ('taken_who1', 'n', ''),
array ('taken_who_sure1', 'n', ''),
array ('taken_where1', 'n', ''),
array ('taken_where_sure1', 'n', ''),
array ('taken_annotation1', 'n', ''),
array ('taken_when2', 'n', ''),
array ('taken_when_sure2', 'n', ''),
array ('taken_who2', 'n', ''),
array ('taken_who_sure2', 'n', ''),
array ('taken_where2', 'n', ''),
array ('taken_where_sure2', 'n', ''),
array ('taken_annotation2', 'n', ''),
array ('received_when1', 'n', ''),
array ('received_when_sure1', 'n', ''),
array ('received_who1', 'n', ''),
array ('received_who_sure1', 'n', ''),
array ('received_where1', 'n', ''),
array ('received_where_sure1', 'n', ''),
array ('received_annotation1', 'n', ''),
array ('received_when2', 'n', ''),
array ('received_when_sure2', 'n', ''),
array ('received_who2', 'n', ''),
array ('received_who_sure2', 'n', ''),
array ('received_where2', 'n', ''),
array ('received_where_sure2', 'n', ''),
array ('received_annotation2', 'n', ''),
array ('printing_plate_produced_when1', 'n', ''),
array ('printing_plate_produced_when_sure1', 'n', ''),
array ('printing_plate_produced_who1', 'n', ''),
array ('printing_plate_produced_who_sure1', 'n', ''),
array ('printing_plate_produced_where1', 'n', ''),
array ('printing_plate_produced_where_sure1', 'n', ''),
array ('printing_plate_produced_annotation1', 'n', ''),
array ('printing_plate_produced_when2', 'n', ''),
array ('printing_plate_produced_when_sure2', 'n', ''),
array ('printing_plate_produced_who2', 'n', ''),
array ('printing_plate_produced_who_sure2', 'n', ''),
array ('printing_plate_produced_where2', 'n', ''),
array ('printing_plate_produced_where_sure2', 'n', ''),
array ('printing_plate_produced_annotation2', 'n', ''),
array ('sent_when1', 'n', ''),
array ('sent_when_sure1', 'n', ''),
array ('sent_who1', 'n', ''),
array ('sent_who_sure1', 'n', ''),
array ('sent_where1', 'n', ''),
array ('sent_where_sure1', 'n', ''),
array ('sent_annotation1', 'n', ''),
array ('sent_when2', 'n', ''),
array ('sent_when_sure2', 'n', ''),
array ('sent_who2', 'n', ''),
array ('sent_who_sure2', 'n', ''),
array ('sent_where2', 'n', ''),
array ('sent_where_sure2', 'n', ''),
array ('sent_annotation2', 'n', ''),
array ('issued_when1', 'n', ''),
array ('issued_when_sure1', 'n', ''),
array ('issued_who1', 'n', ''),
array ('issued_who_sure1', 'n', ''),
array ('issued_where1', 'n', ''),
array ('issued_where_sure1', 'n', ''),
array ('issued_annotation1', 'n', ''),
array ('issued_when2', 'n', ''),
array ('issued_when_sure2', 'n', ''),
array ('issued_who2', 'n', ''),
array ('issued_who_sure2', 'n', ''),
array ('issued_where2', 'n', ''),
array ('issued_where_sure2', 'n', ''),
array ('issued_annotation2', 'n', ''),
array ('signed_when1', 'n', ''),
array ('signed_when_sure1', 'n', ''),
array ('signed_who1', 'n', ''),
array ('signed_who_sure1', 'n', ''),
array ('signed_where1', 'n', ''),
array ('signed_where_sure1', 'n', ''),
array ('signed_annotation1', 'n', ''),
array ('signed_when2', 'n', ''),
array ('signed_when_sure2', 'n', ''),
array ('signed_who2', 'n', ''),
array ('signed_who_sure2', 'n', ''),
array ('signed_where2', 'n', ''),
array ('signed_where_sure2', 'n', ''),
array ('signed_annotation2', 'n', ''),
array ('type_described_when1', 'n', ''),
array ('type_described_when_sure1', 'n', ''),
array ('type_described_who1', 'n', ''),
array ('type_described_who_sure1', 'n', ''),
array ('type_described_where1', 'n', ''),
array ('type_described_where_sure1', 'n', ''),
array ('type_described_annotation1', 'n', ''),
array ('type_described_when2', 'n', ''),
array ('type_described_when_sure2', 'n', ''),
array ('type_described_who2', 'n', ''),
array ('type_described_who_sure2', 'n', ''),
array ('type_described_where2', 'n', ''),
array ('type_described_where_sure2', 'n', ''),
array ('type_described_annotation2', 'n', ''),
array ('drawn_when1', 'n', ''),
array ('drawn_when_sure1', 'n', ''),
array ('drawn_who1', 'n', ''),
array ('drawn_who_sure1', 'n', ''),
array ('drawn_where1', 'n', ''),
array ('drawn_where_sure1', 'n', ''),
array ('drawn_annotation1', 'n', ''),
array ('drawn_when2', 'n', ''),
array ('drawn_when_sure2', 'n', ''),
array ('drawn_who2', 'n', ''),
array ('drawn_who_sure2', 'n', ''),
array ('drawn_where2', 'n', ''),
array ('drawn_where_sure2', 'n', ''),
array ('drawn_annotation2', 'n', ''),
array ('copied_when1', 'n', ''),
array ('copied_when_sure1', 'n', ''),
array ('copied_who1', 'n', ''),
array ('copied_who_sure1', 'n', ''),
array ('copied_where1', 'n', ''),
array ('copied_where_sure1', 'n', ''),
array ('copied_annotation1', 'n', ''),
array ('copied_when2', 'n', ''),
array ('copied_when_sure2', 'n', ''),
array ('copied_who2', 'n', ''),
array ('copied_who_sure2', 'n', ''),
array ('copied_where2', 'n', ''),
array ('copied_where_sure2', 'n', ''),
array ('copied_annotation2', 'n', ''),
array ('has_lived_when1', 'n', ''),
array ('has_lived_when_sure1', 'n', ''),
array ('has_lived_where1', 'n', ''),
array ('has_lived_where_sure1', 'n', ''),
array ('has_lived_annotation1', 'n', ''),
array ('has_lived_when2', 'n', ''),
array ('has_lived_when_sure2', 'n', ''),
array ('has_lived_where2', 'n', ''),
array ('has_lived_where_sure2', 'n', ''),
array ('has_lived_annotation2', 'n', ''),
array ('commissioned_when1', 'n', ''),
array ('commissioned_when_sure1', 'n', ''),
array ('commissioned_who1', 'n', ''),
array ('commissioned_who_sure1', 'n', ''),
array ('commissioned_where1', 'n', ''),
array ('commissioned_where_sure1', 'n', ''),
array ('commissioned_annotation1', 'n', ''),
array ('commissioned_when2', 'n', ''),
array ('commissioned_when_sure2', 'n', ''),
array ('commissioned_who2', 'n', ''),
array ('commissioned_who_sure2', 'n', ''),
array ('commissioned_where2', 'n', ''),
array ('commissioned_where_sure2', 'n', ''),
array ('commissioned_annotation2', 'n', ''),
array ('printed_when1', 'n', ''),
array ('printed_when_sure1', 'n', ''),
array ('printed_who1', 'n', ''),
array ('printed_who_sure1', 'n', ''),
array ('printed_where1', 'n', ''),
array ('printed_where_sure1', 'n', ''),
array ('printed_annotation1', 'n', ''),
array ('printed_when2', 'n', ''),
array ('printed_when_sure2', 'n', ''),
array ('printed_who2', 'n', ''),
array ('printed_who_sure2', 'n', ''),
array ('printed_where2', 'n', ''),
array ('printed_where_sure2', 'n', ''),
array ('printed_annotation2', 'n', ''),
array ('spoken_when1', 'n', ''),
array ('spoken_when_sure1', 'n', ''),
array ('spoken_who1', 'n', ''),
array ('spoken_who_sure1', 'n', ''),
array ('spoken_where1', 'n', ''),
array ('spoken_where_sure1', 'n', ''),
array ('spoken_annotation1', 'n', ''),
array ('spoken_when2', 'n', ''),
array ('spoken_when_sure2', 'n', ''),
array ('spoken_who2', 'n', ''),
array ('spoken_who_sure2', 'n', ''),
array ('spoken_where2', 'n', ''),
array ('spoken_where_sure2', 'n', ''),
array ('spoken_annotation2', 'n', ''),
array ('sung_when1', 'n', ''),
array ('sung_when_sure1', 'n', ''),
array ('sung_who1', 'n', ''),
array ('sung_who_sure1', 'n', ''),
array ('sung_where1', 'n', ''),
array ('sung_where_sure1', 'n', ''),
array ('sung_annotation1', 'n', ''),
array ('sung_when2', 'n', ''),
array ('sung_when_sure2', 'n', ''),
array ('sung_who2', 'n', ''),
array ('sung_who_sure2', 'n', ''),
array ('sung_where2', 'n', ''),
array ('sung_where_sure2', 'n', ''),
array ('sung_annotation2', 'n', ''),
array ('decor_designed_when1', 'n', ''),
array ('decor_designed_when_sure1', 'n', ''),
array ('decor_designed_who1', 'n', ''),
array ('decor_designed_who_sure1', 'n', ''),
array ('decor_designed_where1', 'n', ''),
array ('decor_designed_where_sure1', 'n', ''),
array ('decor_designed_annotation1', 'n', ''),
array ('decor_designed_when2', 'n', ''),
array ('decor_designed_when_sure2', 'n', ''),
array ('decor_designed_who2', 'n', ''),
array ('decor_designed_who_sure2', 'n', ''),
array ('decor_designed_where2', 'n', ''),
array ('decor_designed_where_sure2', 'n', ''),
array ('decor_designed_annotation2', 'n', ''),
array ('form_designed_when1', 'n', ''),
array ('form_designed_when_sure1', 'n', ''),
array ('form_designed_who1', 'n', ''),
array ('form_designed_who_sure1', 'n', ''),
array ('form_designed_where1', 'n', ''),
array ('form_designed_where_sure1', 'n', ''),
array ('form_designed_annotation1', 'n', ''),
array ('form_designed_when2', 'n', ''),
array ('form_designed_when_sure2', 'n', ''),
array ('form_designed_who2', 'n', ''),
array ('form_designed_who_sure2', 'n', ''),
array ('form_designed_where2', 'n', ''),
array ('form_designed_where_sure2', 'n', ''),
array ('form_designed_annotation2', 'n', ''),
array ('modelled_when1', 'n', ''),
array ('modelled_when_sure1', 'n', ''),
array ('modelled_who1', 'n', ''),
array ('modelled_who_sure1', 'n', ''),
array ('modelled_where1', 'n', ''),
array ('modelled_where_sure1', 'n', ''),
array ('modelled_annotation1', 'n', ''),
array ('modelled_when2', 'n', ''),
array ('modelled_when_sure2', 'n', ''),
array ('modelled_who2', 'n', ''),
array ('modelled_who_sure2', 'n', ''),
array ('modelled_where2', 'n', ''),
array ('modelled_where_sure2', 'n', ''),
array ('modelled_annotation2', 'n', ''),
array ('signed_when1', 'n', ''),
array ('signed_when_sure1', 'n', ''),
array ('signed_who1', 'n', ''),
array ('signed_who_sure1', 'n', ''),
array ('signed_where1', 'n', ''),
array ('signed_where_sure1', 'n', ''),
array ('signed_annotation1', 'n', ''),
array ('signed_when2', 'n', ''),
array ('signed_when_sure2', 'n', ''),
array ('signed_who2', 'n', ''),
array ('signed_who_sure2', 'n', ''),
array ('signed_where2', 'n', ''),
array ('signed_where_sure2', 'n', ''),
array ('signed_annotation2', 'n', ''),
array ('was_mentioned_when1', 'n', ''),
array ('was_mentioned_when_sure1', 'n', ''),
array ('was_mentioned_who1', 'n', ''),
array ('was_mentioned_who_sure1', 'n', ''),
array ('was_mentioned_where1', 'n', ''),
array ('was_mentioned_where_sure1', 'n', ''),
array ('was_mentioned_annotation1', 'n', ''),
array ('was_mentioned_when2', 'n', ''),
array ('was_mentioned_when_sure2', 'n', ''),
array ('was_mentioned_who2', 'n', ''),
array ('was_mentioned_who_sure2', 'n', ''),
array ('was_mentioned_where2', 'n', ''),
array ('was_mentioned_where_sure2', 'n', ''),
array ('was_mentioned_annotation2', 'n', ''),
array ('buried_when1', 'n', ''),
array ('buried_when_sure1', 'n', ''),
array ('buried_who1', 'n', ''),
array ('buried_who_sure1', 'n', ''),
array ('buried_where1', 'n', ''),
array ('buried_where_sure1', 'n', ''),
array ('buried_annotation1', 'n', ''),
array ('buried_when2', 'n', ''),
array ('buried_when_sure2', 'n', ''),
array ('buried_who2', 'n', ''),
array ('buried_who_sure2', 'n', ''),
array ('buried_where2', 'n', ''),
array ('buried_where_sure2', 'n', ''),
array ('buried_annotation2', 'n', ''),
array ('intellectual_creation_when1', 'n', ''),
array ('intellectual_creation_when_sure1', 'n', ''),
array ('intellectual_creation_who1', 'n', ''),
array ('intellectual_creation_who_sure1', 'n', ''),
array ('intellectual_creation_where1', 'n', ''),
array ('intellectual_creation_where_sure1', 'n', ''),
array ('intellectual_creation_annotation1', 'n', ''),
array ('intellectual_creation_when2', 'n', ''),
array ('intellectual_creation_when_sure2', 'n', ''),
array ('intellectual_creation_who2', 'n', ''),
array ('intellectual_creation_who_sure2', 'n', ''),
array ('intellectual_creation_where2', 'n', ''),
array ('intellectual_creation_where_sure2', 'n', ''),
array ('intellectual_creation_annotation2', 'n', ''),
array ('painted_on_when1', 'n', ''),
array ('painted_on_when_sure1', 'n', ''),
array ('painted_on_who1', 'n', ''),
array ('painted_on_who_sure1', 'n', ''),
array ('painted_on_where1', 'n', ''),
array ('painted_on_where_sure1', 'n', ''),
array ('painted_on_annotation1', 'n', ''),
array ('painted_on_when2', 'n', ''),
array ('painted_on_when_sure2', 'n', ''),
array ('painted_on_who2', 'n', ''),
array ('painted_on_who_sure2', 'n', ''),
array ('painted_on_where2', 'n', ''),
array ('painted_on_where_sure2', 'n', ''),
array ('painted_on_annotation2', 'n', ''),
array ('illustrated_when1', 'n', ''),
array ('illustrated_when_sure1', 'n', ''),
array ('illustrated_who1', 'n', ''),
array ('illustrated_who_sure1', 'n', ''),
array ('illustrated_where1', 'n', ''),
array ('illustrated_where_sure1', 'n', ''),
array ('illustrated_annotation1', 'n', ''),
array ('illustrated_when2', 'n', ''),
array ('illustrated_when_sure2', 'n', ''),
array ('illustrated_who2', 'n', ''),
array ('illustrated_who_sure2', 'n', ''),
array ('illustrated_where2', 'n', ''),
array ('illustrated_where_sure2', 'n', ''),
array ('illustrated_annotation2', 'n', ''),
);

return;

foreach ($allowed as $values) {
    for ($i = 2; $i < 10; $i++) {
        if (empty($values[$i])) $values[$i] = "";
    }

    echo '
        "' . $values[0] . '" => [';
    if ($values[1] == "y") echo '
            "required"            => true,';
    else echo '
            "required"            => false,';
    echo '
            "allowedValues"       => \'' . $values[3] . '\',';
    if ($values[4] !== 'none' and !empty($values[4])) echo '
            "dependsOn"           => [\'' . $values[4] . '\'],';
    echo '
            "remark"              => \'' . $values[5] . '\',
            "name_human_readable" => $object_basis[\'inventory_number\'],
            "explica"             => $object_basis[\'inv_explica\'],
        ],';

}


